@@ -68,13 +68,15 @@ sub requires {
 ##  }
     return +{
 	'B::Keywords'	=> 0,
-	'Carp'	=> 0,
+	'Carp'		=> 0,
+	'Exporter'	=> 0,
 	'File::Find'	=> 0,
 	'File::Spec'	=> 0,
 	'HTTP::Tiny'	=> 0,
 	'IPC::Cmd'	=> 0,
 	'Module::Load::Conditional'	=> 0,
 	'Pod::Perldoc'			=> 0,
+	'Pod::Simple'			=> 0,
 	'Pod::Simple::LinkSection'	=> 0,
 	'Pod::Simple::PullParser'	=> 0,
 	'Scalar::Util'	=> 0,
@@ -200,7 +202,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2019 by Thomas R. Wyant, III
+Copyright (C) 2019-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
